@@ -31,6 +31,9 @@
 #include <getopt.h>
 #include <errno.h>
 #include <time.h>
+#include <libgen.h>
+#include <inttypes.h>
+#include <limits.h>
 
 #include <libimobiledevice/libimobiledevice.h>
 #include <libimobiledevice/lockdown.h>
@@ -161,8 +164,8 @@ static int zip_f_get_contents(struct zip *zf, const char *filename, int locate_f
 	}
 
 	*buffer = malloc(zs.size);
-	if (zip_fread(zfile, *buffer, zs.size) != zs.size) {
-		fprintf(stderr, "ERROR: zip_fread %ld bytes from '%s'\n", zs.size, filename);
+	if (zs.size > LLONG_MAX || zip_fread(zfile, *buffer, zs.size) != (zip_int64_t)zs.size) {
+		fprintf(stderr, "ERROR: zip_fread %" PRIu64 " bytes from '%s'\n", (uint64_t)zs.size, filename);
 		free(*buffer);
 		*buffer = NULL;
 		zip_fclose(zfile);
